<?php
/**
 * Menu table WP_List_Table based.
 *
 * @package Spam Master
 */

if ( ! class_exists( 'WP_List_Table' ) ) {
	require_once ABSPATH . 'wp-admin/includes/class-wp-list-table.php';
}

/**
 * Main admin menu table class.
 *
 * @since 4.0.1
 */
class SpamMasterAdminMenuTableController extends WP_List_Table {

	/**
	 * Display function.
	 *
	 * @package Spam Master
	 *
	 * @return void
	 */
	public function display() {
		global $wpdb, $blog_id;

		// Add Table & Load Spam Master Options.
		if ( is_multisite() ) {
			$spam_master_keys = $wpdb->get_blog_prefix( $blog_id ) . 'spam_master_keys';
		} else {
			$spam_master_keys = $wpdb->prefix . 'spam_master_keys';
		}
		// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
		$spam_master_status = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_status'" );
		// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
		$spam_master_block_count = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_block_count'" );
		// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
		$spam_master_buffer = $wpdb->get_var( "SELECT COUNT(*) FROM {$spam_master_keys}" );
		// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
		$spam_master_protection_total_number = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_protection_total_number'" );

		// Display buffer size or protection total number.
		if ( $spam_master_block_count >= $spam_master_buffer ) {
			$protection_text = 'Spam Master protected you with <strong>' . number_format( $spam_master_block_count ) . '</strong> blocks.';
		} else {
			$protection_text = 'Spam Master buffer contains <strong>' . number_format( $spam_master_buffer ) . '</strong> entries.';
		}

		// Prepare Settings bubble.
		$spam_master_about_bubble = false;
		if ( empty( $spam_master_status ) || 'EMPTY' === $spam_master_status ) {
			$spam_master_settings_bubble = '<span class="spam-master-top-admin-bar-bubble spam-master-top-admin-yellow" title="Please click Generate Key."><span>1</span></span>';
		}
		if ( empty( $spam_master_status ) || 'INACTIVE' === $spam_master_status ) {
			$spam_master_settings_bubble = '<span class="spam-master-top-admin-bar-bubble spam-master-top-admin-yellow" title="Please click Generate Key."><span>1</span></span>';
		}
		if ( 'VALID' === $spam_master_status ) {
			$spam_master_settings_bubble = '<span class="spam-master-top-admin-bar-bubble spam-master-top-admin-green" title="Congratulations, your connection is Optimal and your website is protected against millions of threats."><span>0</span></span>';
		}
		if ( 'MALFUNCTION_1' === $spam_master_status ) {
			$spam_master_settings_bubble = '<span class="spam-master-top-admin-bar-bubble spam-master-top-admin-orange" title="Please update Spam Master to the latest version."><span>1</span></span>';
		}
		if ( 'MALFUNCTION_2' === $spam_master_status ) {
			$spam_master_settings_bubble = '<span class="spam-master-top-admin-bar-bubble spam-master-top-admin-orange" title="Your key is being used in several websites. Please use 1 key per website. Go online to get more keys."><span>1</span></span>';
		}
		if ( 'MALFUNCTION_3' === $spam_master_status ) {
			$spam_master_settings_bubble = '<span class="spam-master-top-admin-bar-bubble" title="Malfunction 3 detected. Please get in touch with Spam Master support."><span>1</span></span>';
		}
		if ( 'MALFUNCTION_4' === $spam_master_status ) {
			$spam_master_settings_bubble = '<span class="spam-master-top-admin-bar-bubble spam-master-top-admin-orangina" title="Spam Master was not able to generate a connection key. Not to worry, get a free connection key at www.spammaster.org."><span>1</span></span>';
		}
		if ( 'MALFUNCTION_5' === $spam_master_status ) {
			$spam_master_settings_bubble = '<span class="spam-master-top-admin-bar-bubble spam-master-top-admin-orangina" title="Spam Master was not able to generate a connection key because the daily limit of free keys was exceeded. Please try again tomorrow or get pro key."><span>1</span></span>';
		}
		if ( 'MALFUNCTION_6' === $spam_master_status ) {
			$spam_master_settings_bubble = '<span class="spam-master-top-admin-bar-bubble spam-master-top-admin-orangina" title="This Key is assign to another website please go to spammaster.org to verify your keys and or add a new key."><span>1</span></span>';
		}
		if ( 'DISCONNECTED' === $spam_master_status ) {
			$spam_master_settings_bubble = '<span class="spam-master-top-admin-bar-bubble"><span>1</span></span>';
		}
		if ( 'EXPIRED' === $spam_master_status ) {
			$spam_master_settings_bubble = '<span class="spam-master-top-admin-bar-bubble" title="Your key is expired, please renew or get a new key at www.spammaster.org."><span>1</span></span>';
		}
		if ( 'UNSTABLE' === $spam_master_status ) {
			$spam_master_settings_bubble = '<span class="spam-master-top-admin-bar-bubble" title="Spam Master free service is unstable, we apologize for that. Please check the RBL service status at www.spammaster.org."><span>1</span></span>';
		}
		if ( 'HIGH_VOLUME' === $spam_master_status ) {
			$spam_master_settings_bubble = '<span class="spam-master-top-admin-bar-bubble" title="Spam Master detected an High Volume of spam checks from your website using a free key. Please consider a Pro Connection Key."><span>1</span></span>';
		}

		if ( 'VALID' === $spam_master_status || 'MALFUNCTION_1' === $spam_master_status || 'MALFUNCTION_2' === $spam_master_status ) {
			?>
<table class="wp-list-table widefat fixed striped table-view-list" cellspacing="0">
	<thead>
		<tr>
			<th></th>
		</tr>
	</thead>

	<tfoot>
		<tr>
			<th></th>
		</tr>
	</tfoot>

	<tbody>
		<tr class="spam-master-menu-table-bk">
			<td>
				<div class="spam-master-menu-table spam-master-center">
					<p><span class="dashicons dashicons-heart spam-master-admin-f48 spam-master-admin-red spam-master-middle"></span> <span class="spam-master-middle"><?php echo esc_attr( __( 'Spam Master real-time firewall scanning is ', 'spam-master' ) ); ?> <strong><?php echo esc_attr( __( 'On, ', 'spam-master' ) ); ?></strong> <?php echo esc_attr( __( 'you are protected against ', 'spam-master' ) ); ?><strong><?php echo esc_attr( number_format( $spam_master_protection_total_number ) ); ?></strong> <?php echo esc_attr( __( ' million threats and growing daily.', 'spam-master' ) ); ?><span class="dashicons dashicons-shield spam-master-admin-f48 spam-master-admin-green spam-master-middle"></span> <?php echo $protection_text; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?> </span></p>
				</div>
			</td>
		</tr>
		<tr class="spam-master-menu-table-bk">
			<td>
				<div class="spam-master-menu-table">
					<?php echo esc_attr( __( 'Protected:', 'spam-master' ) ); ?> 
					<span class="dashicons dashicons-yes-alt spam-master-admin-green" title="Spam Master Info"></span> <?php echo esc_attr( __( 'Registration Forms', 'spam-master' ) ); ?> 
					<span class="dashicons dashicons-yes-alt spam-master-admin-green" title="Spam Master Info"></span> <?php echo esc_attr( __( 'Login Forms', 'spam-master' ) ); ?> 
					<span class="dashicons dashicons-yes-alt spam-master-admin-green" title="Spam Master Info"></span> <?php echo esc_attr( __( 'Comment Forms', 'spam-master' ) ); ?> 
					<span class="dashicons dashicons-yes-alt spam-master-admin-green" title="Spam Master Info"></span> <?php echo esc_attr( __( 'Contact Forms', 'spam-master' ) ); ?>.
				</div>
			</td>
		</tr>
	</tbody>
</table>

<div class="spam-master-pad-table"></div>

			<?php
		}
	}
}
?>
