<?php
/**
 * Load spam master comment and contact.
 *
 * @package Spam Master
 */

global $wpdb, $blog_id;
// Add Table & Load Spam Master Options.
if ( is_multisite() ) {
	$spam_master_keys = $wpdb->get_blog_prefix( $blog_id ) . 'spam_master_keys';
} else {
	$spam_master_keys = $wpdb->prefix . 'spam_master_keys';
}
// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
$spam_master_status = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_status'" );
// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
$spam_master_comment_strict_on = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_comment_strict_on'" );

// Set malfunctions as VALID.
if ( 'VALID' === $spam_master_status || 'MALFUNCTION_1' === $spam_master_status || 'MALFUNCTION_2' === $spam_master_status ) {
	if ( 'true' === $spam_master_comment_strict_on ) {

		/**
		 * Spam master comment and contact learning.
		 *
		 * @param approved    $approved for learning.
		 * @param commentdata $commentdata for learning.
		 *
		 * @return approved
		 */
		function spam_master_comment_learning( $approved, $commentdata ) {
			global $wpdb, $blog_id;

			// Add Table & Load Spam Master Options.
			if ( is_multisite() ) {
				$spam_master_keys = $wpdb->get_blog_prefix( $blog_id ) . 'spam_master_keys';
			} else {
				$spam_master_keys = $wpdb->prefix . 'spam_master_keys';
			}
			// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
			$spam_master_alert_level = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_alert_level'" );
			// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
			$spam_master_message = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_message'" );
			// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
			$comment_russian_char = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'comment_russian_char'" );
			// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
			$comment_chinese_char = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'comment_chinese_char'" );
			// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
			$comment_asian_char = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'comment_asian_char'" );
			// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
			$comment_arabic_char = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'comment_arabic_char'" );
			// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
			$comment_spam_char = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'comment_spam_char'" );

			// Spam Collect Controller.
			$spam_master_collect_controller = new SpamMasterCollectController();
			$collect_now                    = true;
			$is_collected                   = $spam_master_collect_controller->spammastergetcollect( $collect_now );

			// check Trackback or Comment.
			if ( is_trackback() ) {
				// Spam Master page.
				$spam_master_page = 'Trackback';
				// Spam Initial.
				$spaminitial = 'trackback';

				$blog_threat_type = 'trackback';

				// phpcs:ignore WordPress.Security.NonceVerification.Missing
				if ( ! empty( $_POST['url'] ) ) {
					// phpcs:ignore WordPress.Security.NonceVerification.Missing, WordPress.Security.ValidatedSanitizedInput.InputNotSanitized
					$tb_url = wp_unslash( $_POST['url'] );
				} else {
					$tb_url = 'empty url';
				}
				// phpcs:ignore WordPress.Security.NonceVerification.Missing
				if ( ! empty( $_POST['title'] ) ) {
					// phpcs:ignore WordPress.Security.NonceVerification.Missing, WordPress.Security.ValidatedSanitizedInput.InputNotSanitized
					$title = wp_unslash( $_POST['title'] );
				} else {
					$title = 'empty title';
				}
				// phpcs:ignore WordPress.Security.NonceVerification.Missing
				if ( ! empty( $_POST['excerpt'] ) ) {
					// phpcs:ignore WordPress.Security.NonceVerification.Missing, WordPress.Security.ValidatedSanitizedInput.InputNotSanitized
					$excerpt = wp_unslash( $_POST['excerpt'] );
				} else {
					$excerpt = 'empty excerpt';
				}
				$join_tbs                     = 'URL: ' . $tb_url . ' - NAME: ' . $title . ' - TITLE: ' . $title . ' - EXC: ' . $excerpt;
				$result_comment_content_trim  = substr( $join_tbs, 0, 400 );
				$result_comment_content_clean = wp_strip_all_tags( stripslashes_deep( $result_comment_content_trim ), true );
			} else {
				// Spam Master page.
				$spam_master_page = 'Comment';
				// Spam Initial.
				$spaminitial = 'comment';

				if ( ! empty( $commentdata['comment_content'] ) ) {
					$result_comment_content_trim  = substr( $commentdata['comment_content'], 0, 400 );
					$result_comment_content_clean = wp_strip_all_tags( stripslashes_deep( $result_comment_content_trim ), true );
					$is_spam_char                 = 'true';
				} else {
					// phpcs:ignore WordPress.Security.NonceVerification.Missing
					$result_comment_content_json  = wp_json_encode( $_POST );
					$result_comment_content_trim  = substr( wp_unslash( $result_comment_content_json ), 0, 400 );
					$result_comment_content_clean = wp_strip_all_tags( stripslashes_deep( $result_comment_content_trim ), true );
					$is_spam_char                 = false;
				}
			}

			// Spam Type.
			$spamtype = $spam_master_page;
			// Spam Initial from above.
			if ( empty( $spaminitial ) ) {
				$spaminitial = 'empty';
			}

			// Spam User Controller.
			$spam_master_user_controller = new SpamMasterUserController();
			if ( ! empty( $commentdata['comment_author_email'] ) ) {
				if ( filter_var( $commentdata['comment_author_email'], FILTER_VALIDATE_EMAIL ) ) {
					$spampreemail = wp_strip_all_tags( substr( $commentdata['comment_author_email'], 0, 256 ) );
				} else {
					$spampreemail = false;
				}
			} else {
				$spampreemail = false;
			}
			$is_user = $spam_master_user_controller->spammastergetuser( $spaminitial, $spampreemail );

			// Spam White Controller.
			$spam_master_white_controller = new SpamMasterWhiteController();
			$is_spamadmin                 = $spam_master_white_controller->spammasterwhiteadmin( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $spamtype );
			if ( ! empty( $is_spamadmin ) ) {
				$approved = '1';
				return $approved;
			}

			// Spam White Controller.
			$spam_master_white_controller = new SpamMasterWhiteController();
			$is_white                     = $spam_master_white_controller->spammasterwhitesearch( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $spamtype );
			if ( ! empty( $is_white ) ) {
				$approved = '1';
				return $approved;
			}

			// Spam Buffer Controller.
			$spam_master_buffer_controller = new SpamMasterBufferController();
			$is_buffer                     = $spam_master_buffer_controller->spammasterbuffersearch( $is_collected['remote_ip'], $is_user['blog_threat_email'] );
			if ( ! empty( $is_buffer ) ) {
				$approved = 'spam';
				return $approved;
			}

			// lets do a quick character block.
			$contact_russian_char = false;
			$contact_chinese_char = false;
			$contact_asian_char   = false;
			$contact_arabic_char  = false;
			$contact_spam_char    = false;

			if ( 'true' === $comment_russian_char && 'true' === $is_spam_char ) {
				// Spam ComCon Controller.
				$spam_master_com_con_controller = new SpamMasterComConController();
				$is_char                        = $spam_master_com_con_controller->spammastercharscan( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $spam_master_page, $result_comment_content_clean, $comment_russian_char, $comment_chinese_char, $comment_asian_char, $comment_arabic_char, $comment_spam_char, $contact_russian_char, $contact_chinese_char, $contact_asian_char, $contact_arabic_char, $contact_spam_char );
				if ( $is_char ) {
					$approved = 'spam';
					return $approved;
				}
			}
			if ( 'true' === $comment_chinese_char && 'true' === $is_spam_char ) {
				// Spam ComCon Controller.
				$spam_master_com_con_controller = new SpamMasterComConController();
				$is_char                        = $spam_master_com_con_controller->spammastercharscan( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $spam_master_page, $result_comment_content_clean, $comment_russian_char, $comment_chinese_char, $comment_asian_char, $comment_arabic_char, $comment_spam_char, $contact_russian_char, $contact_chinese_char, $contact_asian_char, $contact_arabic_char, $contact_spam_char );
				if ( $is_char ) {
					$approved = 'spam';
					return $approved;
				}
			}
			if ( 'true' === $comment_asian_char && 'true' === $is_spam_char ) {
				// Spam ComCon Controller.
				$spam_master_com_con_controller = new SpamMasterComConController();
				$is_char                        = $spam_master_com_con_controller->spammastercharscan( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $spam_master_page, $result_comment_content_clean, $comment_russian_char, $comment_chinese_char, $comment_asian_char, $comment_arabic_char, $comment_spam_char, $contact_russian_char, $contact_chinese_char, $contact_asian_char, $contact_arabic_char, $contact_spam_char );
				if ( $is_char ) {
					$approved = 'spam';
					return $approved;
				}
			}
			if ( 'true' === $comment_arabic_char && 'true' === $is_spam_char ) {
				// Spam ComCon Controller.
				$spam_master_com_con_controller = new SpamMasterComConController();
				$is_char                        = $spam_master_com_con_controller->spammastercharscan( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $spam_master_page, $result_comment_content_clean, $comment_russian_char, $comment_chinese_char, $comment_asian_char, $comment_arabic_char, $comment_spam_char, $contact_russian_char, $contact_chinese_char, $contact_asian_char, $contact_arabic_char, $contact_spam_char );
				if ( $is_char ) {
					$approved = 'spam';
					return $approved;
				}
			}
			if ( 'true' === $comment_spam_char && 'true' === $is_spam_char ) {
				// Spam ComCon Controller.
				$spam_master_com_con_controller = new SpamMasterComConController();
				$is_char                        = $spam_master_com_con_controller->spammastercharscan( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $spam_master_page, $result_comment_content_clean, $comment_russian_char, $comment_chinese_char, $comment_asian_char, $comment_arabic_char, $comment_spam_char, $contact_russian_char, $contact_chinese_char, $contact_asian_char, $contact_arabic_char, $contact_spam_char );
				if ( $is_char ) {
					$approved = 'spam';
					return $approved;
				}
			}

			// Spam ComCon Controller.
			$spam_master_com_con_controller = new SpamMasterComConController();
			$is_comcon                      = $spam_master_com_con_controller->spammastercomconscan( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $spam_master_page, $result_comment_content_clean );
			if ( $is_comcon ) {
				$approved = 'spam';
				return $approved;
			} else {
				$approved = '0';
				return $approved;
			}
			// end func comments.
		}
		// end spam_master_comment_strict_on.
		add_filter( 'pre_comment_approved', 'spam_master_comment_learning', 99, 2 );
		add_filter( 'pre_trackback_post', 'spam_master_comment_learning', 99, 2 );
	}
	// end valid.
}

