<?php
/**
 * Load spam master contact form 7.
 *
 * @package Spam Master
 */

global $wpdb, $blog_id;
if ( is_multisite() ) {
	$spam_master_keys = $wpdb->get_blog_prefix( $blog_id ) . 'spam_master_keys';
} else {
	$spam_master_keys = $wpdb->prefix . 'spam_master_keys';
}
// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
$spam_master_status = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_status'" );
// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
$spam_master_cache_proxie = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_cache_proxie'" );

if ( 'VALID' === $spam_master_status || 'MALFUNCTION_1' === $spam_master_status || 'MALFUNCTION_2' === $spam_master_status ) {

	/**
	 * Spam master firewall.
	 *
	 * @return void
	 */
	function spam_master_frontend_firewall() {
		global $wpdb, $blog_id;

		if ( is_multisite() ) {
			$spam_master_keys = $wpdb->get_blog_prefix( $blog_id ) . 'spam_master_keys';
		} else {
			$spam_master_keys = $wpdb->prefix . 'spam_master_keys';
		}
		// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
		$spam_master_firewall_on = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_firewall_on'" );
		// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
		$spam_master_alert_level = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_alert_level'" );
		// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
		$spam_master_firewall_page = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_firewall_page'" );

		// Spam Master page.
		$spam_master_page = 'HAF';
		// Spam Type.
		$spamtype = 'HAF';

		// Disc notifications.
		// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
		$spam_master_type = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_type'" );
		// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
		$spamsend = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_disc_not'" );
		// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
		$spamsenddate = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_disc_not_date'" );
		// Get the date short.
		$spam_master_current_date = current_datetime()->format( 'Y-m-d' );
		if ( 'TRIAL' === $spam_master_type || 'FREE' === $spam_master_type ) {
			$spammasterdiscdate = $spam_master_current_date;
			$spamdesc           = false;
			$spamdescper        = false;
			$spamcode           = false;
			if ( '2024-01-01' === $spam_master_current_date ) {
				$spamdesc    = 'New Year';
				$spamdescper = '50%';
				$spamcode    = 'NEWYPRO50';
			}
			if ( '2023-02-14' === $spam_master_current_date ) {
				$spamdesc    = 'Valentines Day';
				$spamdescper = '50%';
				$spamcode    = 'VALENTINEPRO50';
			}
			if ( '2023-04-01' === $spam_master_current_date ) {
				$spamdesc    = 'Spring';
				$spamdescper = '25%';
				$spamcode    = 'SPRINGRO25';
			}
			if ( '2023-06-20' === $spam_master_current_date ) {
				$spamdesc    = 'Summer';
				$spamdescper = '25%';
				$spamcode    = 'SUMMERPRO25';
			}
			if ( '2023-08-01' === $spam_master_current_date ) {
				$spamdesc    = 'August';
				$spamdescper = '25%';
				$spamcode    = 'AUGUSTPRO25';
			}
			if ( '2023-10-31' === $spam_master_current_date ) {
				$spamdesc    = 'Halloween';
				$spamdescper = '50%';
				$spamcode    = 'HALLOWEENPRO50';
			}
			if ( '2023-11-24' === $spam_master_current_date ) {
				$spamdesc    = 'Black Friday';
				$spamdescper = '25%';
				$spamcode    = 'BLACKPRO25';
			}
			if ( '2023-11-27' === $spam_master_current_date ) {
				$spamdesc    = 'Cyber Monday';
				$spamdescper = '50%';
				$spamcode    = 'CYBERPRO50';
			}
			if ( '2023-12-25' === $spam_master_current_date ) {
				$spamdesc    = 'Christmas';
				$spamdescper = '25%';
				$spamcode    = 'XMASPRO25';
			}
			if ( '0' === $spamsend && $spammasterdiscdate !== $spamsenddate && ! empty( $spamdesc ) && ! empty( $spamdescper ) && ! empty( $spamcode ) ) {
				// Call email controller.
				$spammail                     = true;
				$spam_master_email_controller = new SpamMasterEmailController();
				$is_email                     = $spam_master_email_controller->spammasterdiscnotify( $spammasterdiscdate, $spamdesc, $spamdescper, $spamcode, $spamsend );
			}
		}

		// Spam Collect Controller.
		$spam_master_collect_controller = new SpamMasterCollectController();
		$collect_now                    = true;
		$is_collected                   = $spam_master_collect_controller->spammastergetcollect( $collect_now );

		// Spam User Controller.
		$spam_master_user_controller = new SpamMasterUserController();
		// Spam Initial.
		$spaminitial  = 'haf';
		$spampreemail = false;
		$is_user      = $spam_master_user_controller->spammastergetuser( $spaminitial, $spampreemail );

		// Spam White Controller.
		$spam_master_white_controller = new SpamMasterWhiteController();
		$is_spamadmin                 = $spam_master_white_controller->spammasterwhiteadmin( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $spamtype );
		if ( ! empty( $is_spamadmin ) ) {
			$yesitisa = true;
		} else {
			// Spam White Controller.
			$spam_master_white_controller = new SpamMasterWhiteController();
			$is_white                     = $spam_master_white_controller->spammasterwhitesearch( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $spamtype );
			if ( ! empty( $is_white ) ) {
				$yesitis = true;
			} else {
				// Spam Buffer Controller.
				$spam_master_buffer_controller = new SpamMasterBufferController();
				$is_buffer                     = $spam_master_buffer_controller->spammasterbuffersearch( $is_collected['remote_ip'], $is_user['blog_threat_email'] );
				if ( ! empty( $is_buffer ) ) {

					if ( 'true' === $spam_master_firewall_on ) {

						// Firewall Page.
						wp_safe_redirect( $spam_master_firewall_page );
						exit();

					}
				} else {
					// Token.
					$pam_master_length = 25;
					$spam_master_token = bin2hex( random_bytes( $pam_master_length ) );
					// Session.
					if ( ! isset( $_SESSION ) ) {
						session_start();
					}
					if ( isset( $_SESSION['spam-master-token'] ) ) {
						$itiss = true;
					} else {
						$_SESSION['spam-master-token'] = $spam_master_token;
					}
					// phpcs:ignore WordPress.Security.NonceVerification.Missing
					if ( ! empty( $_POST ) && ! is_user_logged_in() ) {
						// phpcs:ignore WordPress.Security.NonceVerification.Missing
						$spam_elusive = $_POST;
						// Spam Elusive Controller for json. Future need to scan json.
						$spam_master_elusive_controller = new SpamMasterElusiveController();
						$is_json                        = $spam_master_elusive_controller->spammasterisjson( $spam_elusive );
						if ( 'bail' !== $is_json ) {
							$blog_threat_email = $is_json;
							// Spam HAF Controller.
							$spam_master_haf_controller = new SpamMasterHAFController();
							$is_haf                     = $spam_master_haf_controller->spammasterhaf( $is_collected['remote_ip'], $blog_threat_email, $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'] );
						} else {
							// Spam Elusive Controller.
							$spam_master_elusive_controller = new SpamMasterElusiveController();
							$is_elusive                     = $spam_master_elusive_controller->spammasterelusive( $spam_elusive );
							if ( ! empty( $is_elusive ) && 'bail' !== $is_elusive ) {
								$blog_threat_email = $is_elusive;
								// Spam HAF Controller.
								$spam_master_haf_controller = new SpamMasterHAFController();
								$is_haf                     = $spam_master_haf_controller->spammasterhaf( $is_collected['remote_ip'], $blog_threat_email, $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'] );
							}
						}
					}
				}
			}
		}
	}
	// Login page.
	// add_action( 'login_init', 'spam_master_frontend_firewall' );
	// Admin pages.
	// add_action('admin_init', 'spam_master_frontend_firewall');
	// Frontend pages.
	add_action( 'init', 'spam_master_frontend_firewall' );

	// IMPLEMENT PROXY FRONTEND.
	if ( 'true' === $spam_master_cache_proxie ) {

		/**
		 * Cache Control.
		 *
		 * @return void
		 */
		function spam_master_no_cache() {
			global $wpdb, $blog_id;

			session_cache_limiter( '' );
			header( 'Cache-Control: no-store' );
			if ( ! session_id() ) {
				session_start();
			}
		}
		add_action( 'init', 'spam_master_no_cache', 0 );
	}

	// End Valid.
}

