<?php
/**
 * Load spam master registration.
 *
 * @package Spam Master
 */

global $wpdb, $blog_id;
// Add Table & Load Spam Master Options.
if ( is_multisite() ) {
	$spam_master_keys = $wpdb->get_blog_prefix( $blog_id ) . 'spam_master_keys';
} else {
	$spam_master_keys = $wpdb->prefix . 'spam_master_keys';
}
// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
$spam_master_status = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_status'" );

// Multisite Block.
if ( is_multisite() ) {
	// post data if license status is valid.
	if ( 'VALID' === $spam_master_status || 'MALFUNCTION_1' === $spam_master_status || 'MALFUNCTION_2' === $spam_master_status ) {

		/**
		 * Spam master registration learning multi site.
		 *
		 * @param result $result for learning.
		 *
		 * @return result
		 */
		function spam_master_registration_multi( $result ) {
			global $wpdb, $blog_id;

			// Add Table & Load Spam Master Options.
			if ( is_multisite() ) {
				$spam_master_keys = $wpdb->get_blog_prefix( $blog_id ) . 'spam_master_keys';
			} else {
				$spam_master_keys = $wpdb->prefix . 'spam_master_keys';
			}
			// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
			$spam_master_alert_level = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_alert_level'" );
			// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
			$spam_master_message = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_message'" );

			// Spam Master page.
			$spam_master_page = 'Registration';

			// Spam Collect Controller.
			$spam_master_collect_controller = new SpamMasterCollectController();
			$collect_now                    = true;
			$is_collected                   = $spam_master_collect_controller->spammastergetcollect( $collect_now );

			// Spam User Controller.
			$spam_master_user_controller = new SpamMasterUserController();
			$spaminitial                 = 'registration';
			if ( ! empty( $result['user_email'] ) ) {
				if ( filter_var( $result['user_email'], FILTER_VALIDATE_EMAIL ) ) {
					$spampreemail = wp_strip_all_tags( substr( $result['user_email'], 0, 256 ) );
				} else {
					$spampreemail = false;
				}
			} else {
				$spampreemail = false;
			}
			$is_user = $spam_master_user_controller->spammastergetuser( $spaminitial, $spampreemail );

			// Spam White Controller.
			$spamtype                     = $spam_master_page;
			$spam_master_white_controller = new SpamMasterWhiteController();
			$is_spamadmin                 = $spam_master_white_controller->spammasterwhiteadmin( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $spamtype );
			if ( ! empty( $is_spamadmin ) ) {
				$itis = true;
			}

			// Spam White Controller.
			$spamtype                     = $spam_master_page;
			$spam_master_white_controller = new SpamMasterWhiteController();
			$is_white                     = $spam_master_white_controller->spammasterwhitesearch( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $spamtype );
			if ( ! empty( $is_white ) ) {
				$itis = true;
			}

			// Spam Buffer Controller.
			$spam_master_buffer_controller = new SpamMasterBufferController();
			$is_buffer                     = $spam_master_buffer_controller->spammasterbuffersearch( $is_collected['remote_ip'], $is_user['blog_threat_email'] );
			if ( ! empty( $is_buffer ) ) {
				// phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				echo '<p class="error"><strong>SPAM MASTER</strong> ' . $spam_master_message . '</p>';
				exit();
			}

			// Spam Registration Controller.
			$spam_master_registration_controller = new SpamMasterRegistrationController();
			$is_register                         = $spam_master_registration_controller->spammasterregister( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $spam_master_page );
			if ( $is_register ) {
				// phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				echo '<p class="error"><strong>SPAM MASTER</strong> ' . $spam_master_message . '</p>';
				exit();
			}

			return $result;
			// end func.
		}
		add_filter( 'wpmu_validate_user_signup', 'spam_master_registration_multi', 99 );
		// end valid.
	}
	// end multi.
} else {
	// SingleSite Block.
	// post data if license status is valid.
	if ( 'VALID' === $spam_master_status || 'MALFUNCTION_1' === $spam_master_status || 'MALFUNCTION_2' === $spam_master_status ) {

		/**
		 * Spam master registration learning single site.
		 *
		 * @param user_login $user_login for learning.
		 * @param user_email $user_email for learning.
		 * @param errors     $errors for learning.
		 *
		 * @return errors
		 */
		function spam_master_registration( $user_login, $user_email, $errors ) {
			global $wpdb, $blog_id;

			// Add Table & Load Spam Master Options.
			if ( is_multisite() ) {
				$spam_master_keys = $wpdb->get_blog_prefix( $blog_id ) . 'spam_master_keys';
			} else {
				$spam_master_keys = $wpdb->prefix . 'spam_master_keys';
			}
			// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
			$spam_master_alert_level = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_alert_level'" );
			// phpcs:ignore WordPress.DB.DirectDatabaseQuery.DirectQuery, WordPress.DB.DirectDatabaseQuery.NoCaching, WordPress.DB.PreparedSQL.InterpolatedNotPrepared
			$spam_master_message = $wpdb->get_var( "SELECT spamvalue FROM {$spam_master_keys} WHERE spamkey = 'Option' AND spamtype = 'spam_master_message'" );

			// Spam Master page.
			$spam_master_page = 'Registration';

			// Spam Collect Controller.
			$spam_master_collect_controller = new SpamMasterCollectController();
			$collect_now                    = true;
			$is_collected                   = $spam_master_collect_controller->spammastergetcollect( $collect_now );

			// Spam User Controller.
			$spam_master_user_controller = new SpamMasterUserController();
			$spaminitial                 = 'registration';
			if ( ! empty( $user_email ) ) {
				if ( filter_var( $user_email, FILTER_VALIDATE_EMAIL ) ) {
					$spampreemail = wp_strip_all_tags( substr( $user_email, 0, 256 ) );
				} else {
					$spampreemail = false;
				}
			} else {
				$spampreemail = false;
			}
			$is_user = $spam_master_user_controller->spammastergetuser( $spaminitial, $spampreemail );

			// Spam White Controller.
			$spamtype                     = $spam_master_page;
			$spam_master_white_controller = new SpamMasterWhiteController();
			$is_spamadmin                 = $spam_master_white_controller->spammasterwhiteadmin( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $spamtype );
			if ( ! empty( $is_spamadmin ) ) {
				return;
			}

			// Spam White Controller.
			$spamtype                     = $spam_master_page;
			$spam_master_white_controller = new SpamMasterWhiteController();
			$is_white                     = $spam_master_white_controller->spammasterwhitesearch( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $spamtype );
			if ( ! empty( $is_white ) ) {
				return;
			}

			// Spam Buffer Controller.
			$spam_master_buffer_controller = new SpamMasterBufferController();
			$is_buffer                     = $spam_master_buffer_controller->spammasterbuffersearch( $is_collected['remote_ip'], $is_user['blog_threat_email'] );
			if ( ! empty( $is_buffer ) ) {
				$errors->add( 'invalid_email', '<strong>SPAM MASTER</strong> ' . $spam_master_message );
				return;
			}

			// Spam Registration Controller.
			$spam_master_registration_controller = new SpamMasterRegistrationController();
			$is_register                         = $spam_master_registration_controller->spammasterregister( $is_collected['remote_ip'], $is_user['blog_threat_email'], $is_collected['remote_referer'], $is_collected['dest_url'], $is_collected['remote_agent'], $is_user['spamuserA'], $spam_master_page );
			if ( $is_register ) {
				$errors->add( 'invalid_email', '<strong>SPAM MASTER</strong> ' . $spam_master_message );
				return;
			}
			// end func.
		}
		add_action( 'register_post', 'spam_master_registration', 11, 3 );
		// end valid.
	}
	// end single.
}
